==> billogram-foundation-2.4.0.tgz: package/modules/components/textbox/TextboxContainer.jest.js <==
import React from 'react';
import ReactDOM from 'react-dom';
import TestUtils from 'react-addons-test-utils';
import purebem from 'purebem';
import { Provider } from 'react-redux';

import Textbox from './Textbox';
import TextboxContainer, { changeType } from './TextboxContainer';

import textboxChange from './redux-actions/textboxChange';
import textboxTextState from './textboxTextState';

import createStore from '../../test-utils/createStore';


const TestTextbox = Textbox({
    block: purebem.of('test-textbox'),
    displayName: 'TestTextbox'
});

const TestTextboxContainer = TextboxContainer({
    Component: TestTextbox
});

describe('TextboxContainer', () => {
    const path = 'text';
    const root = 'test';
    const actionTypePrefix = 'TEST-TEXTBOX';

    it('should dispatch change event on change', () => {
        const store = createStore({
            test: {
                text: textboxTextState()
            }
        });

        const provider = TestUtils.renderIntoDocument(
            <Provider store={ store }>
                <TestTextboxContainer
                    actionTypePrefix={ actionTypePrefix }
                    path={ path }
                    root={ root } />
            </Provider>
        );

        const container = TestUtils.findRenderedComponentWithType(provider, TestTextboxContainer);
        const node = ReactDOM.findDOMNode(container);
        node.value = 'a';

        TestUtils.Simulate.change(node);

        const actions = store.getState().actions;

        expect(actions.length).toBe(1);
        expect(actions[0]).toEqual(textboxChange({
            path,
            root,
            type: changeType(actionTypePrefix),
            rawValue: 'a',
            value: 'a'
        }));
    });

    it('should read value from store', () => {
        const store = createStore({
            test: {
                text: textboxTextState({ rawValue: 'a', value: 'a' })
            }
        });

        const provider = TestUtils.renderIntoDocument(
            <Provider store={ store }>
                <TestTextboxContainer
                    actionTypePrefix={ actionTypePrefix }
                    path={ path }
                    root={ root } />
            </Provider>
        );

        const container = TestUtils.findRenderedComponentWithType(provider, TestTextbox);
        const node = ReactDOM.findDOMNode(container);

        expect(node.value).toBe('a');
    });

});

==> billogram-foundation-3.5.0.tgz: package/modules/components/textbox/TextboxContainer.jest.js <==
import React from 'react';
import ReactDOM from 'react-dom';
import TestUtils from 'react-addons-test-utils';
import purebem from 'purebem';
import { Provider } from 'react-redux';

import Textbox from './Textbox';
import TextboxContainer, { changeType } from './TextboxContainer';

import textboxChange from './redux/textboxChange';
import textboxTextState from './textboxTextState';

import createStore from '../../test-utils/createStore';


const TestTextbox = Textbox({
    block: purebem.of('test-textbox'),
    displayName: 'TestTextbox'
});

const TestTextboxContainer = TextboxContainer({
    Component: TestTextbox
});

describe('TextboxContainer', () => {
    const path = 'text';
    const root = 'test';
    const actionTypePrefix = 'TEST-TEXTBOX';

    it('should dispatch change event on change', () => {
        const store = createStore({
            test: {
                text: textboxTextState()
            }
        });

        const provider = TestUtils.renderIntoDocument(
            <Provider store={ store }>
                <TestTextboxContainer
                    actionTypePrefix={ actionTypePrefix }
                    path={ path }
                    root={ root } />
            </Provider>
        );

        const container = TestUtils.findRenderedComponentWithType(provider, TestTextboxContainer);
        const node = ReactDOM.findDOMNode(container);
        node.value = 'a';

        TestUtils.Simulate.change(node);

        const actions = store.getState().actions;

        expect(actions.length).toBe(1);
        expect(actions[0]).toEqual(textboxChange({
            path,
            root,
            type: changeType(actionTypePrefix),
            rawValue: 'a',
            value: 'a'
        }));
    });

    it('should read value from store', () => {
        const store = createStore({
            test: {
                text: textboxTextState({ rawValue: 'a', value: 'a' })
            }
        });

        const provider = TestUtils.renderIntoDocument(
            <Provider store={ store }>
                <TestTextboxContainer
                    actionTypePrefix={ actionTypePrefix }
                    path={ path }
                    root={ root } />
            </Provider>
        );

        const container = TestUtils.findRenderedComponentWithType(provider, TestTextbox);
        const node = ReactDOM.findDOMNode(container);

        expect(node.value).toBe('a');
    });

});
